# tomodoro
A pomodoro timer in a simple TUI.

<img width="589" alt="tomodomo" src="https://github.com/user-attachments/assets/0cb5aa87-5534-40f4-9edb-e151bdcb9f9e" />

## Run
`uvx tomodoro`

## Controls
- `s`: stop/start
- `w`: work timer
- `b`: break timer
- `q`: quit
